@@ -4,5 +4,7 @@ copyLSN2temp <- function() {
   file.copy(from = system.file("lsndata/MiddleFork04.ssn",package = "SSN"), 
     to = tempdir(), recursive = TRUE,
     overwrite = FALSE, copy.mode = FALSE)
+  if(.Platform$OS.type == 'unix') 
+		system(paste0('chmod -R 777 ', tempdir(),'/MiddleFork04.ssn'))
 }
 
